==> scalarx_2.10-0.2.3-JS.jar: rx/ops/Timer$.js <==
/** @constructor */
ScalaJS.c.rx_ops_Timer$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_ops_Timer$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_ops_Timer$.prototype.constructor = ScalaJS.c.rx_ops_Timer$;
ScalaJS.c.rx_ops_Timer$.prototype.apply__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext__Lrx_ops_Timer = (function(interval, delay, scheduler, p, ec) {
  return new ScalaJS.c.rx_ops_Timer().init___Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext(interval, delay, scheduler, p, ec)
});
ScalaJS.c.rx_ops_Timer$.prototype.apply$default$2__Lscala_concurrent_duration_FiniteDuration = (function() {
  return new ScalaJS.c.scala_concurrent_duration_package$DurationInt().init___I(ScalaJS.modules.scala_concurrent_duration_package().DurationInt__I__I(0)).seconds__Lscala_concurrent_duration_FiniteDuration()
});
ScalaJS.c.rx_ops_Timer$.prototype.apply__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext__ = (function(interval, delay, scheduler, p, ec) {
  return this.apply__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext__Lrx_ops_Timer(interval, delay, scheduler, p, ec)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Timer$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Timer$.prototype = ScalaJS.c.rx_ops_Timer$.prototype;
ScalaJS.is.rx_ops_Timer$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Timer$)))
});
ScalaJS.as.rx_ops_Timer$ = (function(obj) {
  if ((ScalaJS.is.rx_ops_Timer$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Timer")
  }
});
ScalaJS.isArrayOf.rx_ops_Timer$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Timer$)))
});
ScalaJS.asArrayOf.rx_ops_Timer$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Timer$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Timer;", depth)
  }
});
ScalaJS.data.rx_ops_Timer$ = new ScalaJS.ClassTypeData({
  rx_ops_Timer$: 0
}, false, "rx.ops.Timer$", ScalaJS.data.java_lang_Object, {
  rx_ops_Timer$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Timer$.prototype.$classData = ScalaJS.data.rx_ops_Timer$;
ScalaJS.moduleInstances.rx_ops_Timer = undefined;
ScalaJS.modules.rx_ops_Timer = (function() {
  if ((!ScalaJS.moduleInstances.rx_ops_Timer)) {
    ScalaJS.moduleInstances.rx_ops_Timer = new ScalaJS.c.rx_ops_Timer$().init___()
  };
  return ScalaJS.moduleInstances.rx_ops_Timer
});
//@ sourceMappingURL=Timer$.js.map

==> scalarx_2.10-0.2.4-JS.jar: rx/ops/Timer$.js <==
/** @constructor */
ScalaJS.c.rx_ops_Timer$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_ops_Timer$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_ops_Timer$.prototype.constructor = ScalaJS.c.rx_ops_Timer$;
ScalaJS.c.rx_ops_Timer$.prototype.apply__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext__Lrx_ops_Timer = (function(interval, delay, scheduler, p, ec) {
  return new ScalaJS.c.rx_ops_Timer().init___Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext(interval, delay, scheduler, p, ec)
});
ScalaJS.c.rx_ops_Timer$.prototype.apply$default$2__Lscala_concurrent_duration_FiniteDuration = (function() {
  return new ScalaJS.c.scala_concurrent_duration_package$DurationInt().init___I(ScalaJS.modules.scala_concurrent_duration_package().DurationInt__I__I(0)).seconds__Lscala_concurrent_duration_FiniteDuration()
});
ScalaJS.c.rx_ops_Timer$.prototype.apply$default$2__ = (function() {
  return this.apply$default$2__Lscala_concurrent_duration_FiniteDuration()
});
ScalaJS.c.rx_ops_Timer$.prototype.apply__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext__ = (function(interval, delay, scheduler, p, ec) {
  return this.apply__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lrx_core_Propagator__Lscala_concurrent_ExecutionContext__Lrx_ops_Timer(interval, delay, scheduler, p, ec)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Timer$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Timer$.prototype = ScalaJS.c.rx_ops_Timer$.prototype;
ScalaJS.is.rx_ops_Timer$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Timer$)))
});
ScalaJS.as.rx_ops_Timer$ = (function(obj) {
  if ((ScalaJS.is.rx_ops_Timer$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Timer")
  }
});
ScalaJS.isArrayOf.rx_ops_Timer$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Timer$)))
});
ScalaJS.asArrayOf.rx_ops_Timer$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Timer$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Timer;", depth)
  }
});
ScalaJS.data.rx_ops_Timer$ = new ScalaJS.ClassTypeData({
  rx_ops_Timer$: 0
}, false, "rx.ops.Timer$", ScalaJS.data.java_lang_Object, {
  rx_ops_Timer$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Timer$.prototype.$classData = ScalaJS.data.rx_ops_Timer$;
ScalaJS.moduleInstances.rx_ops_Timer = undefined;
ScalaJS.modules.rx_ops_Timer = (function() {
  if ((!ScalaJS.moduleInstances.rx_ops_Timer)) {
    ScalaJS.moduleInstances.rx_ops_Timer = new ScalaJS.c.rx_ops_Timer$().init___()
  };
  return ScalaJS.moduleInstances.rx_ops_Timer
});
//@ sourceMappingURL=Timer$.js.map
